@@ -4,7 +4,7 @@
 
 package Mason::Compilation;
 BEGIN {
-  $Mason::Compilation::VERSION = '2.19';
+  $Mason::Compilation::VERSION = '2.20';
 }
 use File::Basename qw(dirname);
 use Guard;
@@ -433,7 +433,9 @@ method _handle_substitution ( $text, $filter_list ) {
     if ($filter_list) {
         if ( my @filters = grep { /\S/ } split( /\s*,\s*/, $filter_list ) ) {
             my $filter_call_list = join( ", ", map { "\$self->$_()" } @filters );
-            $text = sprintf( '$self->m->_apply_filters(%s, sub { %s })', $filter_call_list, $text );
+            $text =
+              sprintf( '$self->m->_apply_filters(%s, sub { local $_ = %s; defined($_) ? $_ : "" })',
+                $filter_call_list, $text );
         }
     }
 
@@ -736,14 +738,18 @@ method _output_cmeta () {
         class        => 'CLASS',
         interp       => '$interp',
     );
-    return join( "\n",
+    return join(
+        "\n",
         "method _set_class_cmeta (\$interp) {",
         "\$_class_cmeta = \$interp->component_class_meta_class->new(",
-        ( map { sprintf( "'%s' => %s,", $_, $cmeta_info{$_} ) } sort( keys(%cmeta_info) ) ),
-        ');',
-        '}',
+        (
+            map { sprintf( "'%s' => %s,", $_, $cmeta_info{$_} ) }
+            sort( keys(%cmeta_info) )
+        ),
+        ');', '}',
         'sub _unset_class_cmeta { undef $_class_cmeta }',
-        'sub _class_cmeta { $_class_cmeta }' );
+        'sub _class_cmeta { $_class_cmeta }'
+    );
 }
 
 method _output_compiled_component () {
@@ -826,8 +832,8 @@ method _output_methods () {
 
     # Sort methods so that modifiers come after
     #
-    my @sorted_methods_keys = sort { ( index( $a, ' ' ) <=> index( $b, ' ' ) ) || $a cmp $b }
-      keys( %{ $self->{methods} } );
+    my @sorted_methods_keys =
+      sort { ( index( $a, ' ' ) <=> index( $b, ' ' ) ) || $a cmp $b } keys( %{ $self->{methods} } );
     return
       join( "\n", map { $self->_output_method( $self->{methods}->{$_} ) } @sorted_methods_keys );
 }
@@ -956,7 +962,7 @@ Jonathan Swartz <swartz@pobox.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jonathan Swartz.
+This software is copyright (c) 2012 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
