@@ -1,6 +1,6 @@
 package Mason::Component;
 BEGIN {
-  $Mason::Component::VERSION = '2.19';
+  $Mason::Component::VERSION = '2.20';
 }
 use Moose;    # no Mason::Moose - don't want StrictConstructor
 use MooseX::HasDefaults::RO;
@@ -15,6 +15,8 @@ with 'Mason::Filters::Standard';
 has 'args' => ( init_arg => undef, lazy_build => 1 );
 has 'm'    => ( required => 1, weak_ref => 1 );
 
+__PACKAGE__->meta->make_immutable();
+
 method BUILD ($params) {
 
     # Make a copy of params and re-weaken m
@@ -29,7 +31,10 @@ method cmeta () {
 
 method _build_args () {
     my $orig_params = $self->{_orig_params};
-    return { map { ( $_, $orig_params->{$_} ) } grep { $_ ne 'm' } keys(%$orig_params) };
+    return {
+        map { ( $_, $orig_params->{$_} ) }
+        grep { $_ ne 'm' } keys(%$orig_params)
+    };
 }
 
 # Default handle - call render
@@ -62,8 +67,6 @@ method no_wrap ($class:) {
     $class->meta->add_method( 'render' => sub { $_[0]->main(@_) } );
 }
 
-__PACKAGE__->meta->make_immutable();
-
 1;
 
 
@@ -96,8 +99,6 @@ of a request).
 
 In many cases only C<main> will actually do anything.
 
-=for html <a name="handle" />
-
 =over
 
 =item handle
@@ -128,16 +129,12 @@ render the page
 It should not output any content itself. By default, it simply calls
 L<render|/render>.
 
-=for html <a name="render" />
-
 =item render
 
 This method is invoked from L<handle|/handle> on the page component. Its job is
 to output the full content of the page. By default, it simply calls
 L<wrap|/wrap>.
 
-=for html <a name="wrap" />
-
 =item wrap
 
 This method is invoked from L<render|/render> on the page component.  By
@@ -170,8 +167,6 @@ To do no wrapping at all, call the component class method L</no_wrap>:
     CLASS->no_wrap;
     </%class>
 
-=for html <a name="main" />
-
 =item main
 
 This method is invoked when a non-page component is called, and from the
@@ -209,8 +204,6 @@ L<Mason::Manual::RequestDispatch/Partial Paths|Mason::Manual::RequestDispatch>.
 
 =head1 OTHER METHODS
 
-=for html <a name="args" />
-
 =over
 
 =item args
@@ -218,8 +211,6 @@ L<Mason::Manual::RequestDispatch/Partial Paths|Mason::Manual::RequestDispatch>.
 Returns the hashref of arguments passed to this component's constructor, e.g.
 the arguments passed in a L<component call|/CALLING COMPONENTS>.
 
-=for html <a name="cmeta" />
-
 =item cmeta
 
 Returns the L<Mason::Component::ClassMeta> object associated with this
@@ -228,8 +219,6 @@ file.
 
     my $path = $self->cmeta->path;
 
-=for html <a name="m" />
-
 =item m
 
 Returns the current request. This is also available via C<< $m >> inside Mason
@@ -247,7 +236,7 @@ Jonathan Swartz <swartz@pobox.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jonathan Swartz.
+This software is copyright (c) 2012 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
