@@ -1,6 +1,6 @@
 package Mason::Interp;
 BEGIN {
-  $Mason::Interp::VERSION = '2.19';
+  $Mason::Interp::VERSION = '2.20';
 }
 use Carp;
 use Devel::GlobalDestruction;
@@ -468,7 +468,6 @@ method _build_match_request_path ($interp:) {
     my $ignore_file_regex =
       '(/' . join( "|", @{ $interp->autobase_names }, @{ $interp->dhandler_names } ) . ')$';
     $ignore_file_regex = qr/$ignore_file_regex/;
-    my %is_dhandler_name = map { ( $_, 1 ) } @{ $interp->dhandler_names };
     my @autoextensions = $interp->autoextend_request_path ? @{ $interp->top_level_extensions } : ();
     my @index_names = @{ $interp->index_names };
     undef $interp;    # So this doesn't end up in closure and cause cycle
@@ -482,6 +481,10 @@ method _build_match_request_path ($interp:) {
         my $path           = $request_path;
         my @tried_paths;
 
+        # Deal with trailing slash
+        #
+        $path_info = chop($path) if $path ne '/' && substr( $path, -1 ) eq '/';
+
         while (1) {
             my @candidate_paths =
                 ( $path_info eq '' && !@autoextensions ) ? ($path)
@@ -508,9 +511,12 @@ method _build_match_request_path ($interp:) {
             }
             $interp->_top_level_not_found( $request_path, \@tried_paths ) if $path eq '/';
             my $name = basename($path);
-            $path_info = length($path_info) ? "$name/$path_info" : $name;
-            $path = dirname($path);
-            @index_subpaths = ();    # only match index file in same directory
+            $path_info =
+                $path_info eq '/' ? "$name/"
+              : length($path_info) ? "$name/$path_info"
+              :                      $name;
+            $path           = dirname($path);
+            @index_subpaths = ();               # only match index file in same directory
         }
     };
 }
@@ -786,8 +792,6 @@ the cache of loaded components.
 
 =head1 PARAMETERS TO THE new() CONSTRUCTOR
 
-=for html <a name="allow_globals" />
-
 =over
 
 =item allow_globals (varnames)
@@ -804,24 +808,18 @@ example, creates a C<< $c >> global set to the context object in each request.
 
 Set the values of globals with L<set_global|/set_global>.
 
-=for html <a name="autobase_names" />
-
 =item autobase_names
 
 Array reference of L<autobase|Mason::Manual/Autobase components> filenames to
 check in order when determining a component's superclass. Default is C<<
 ["Base.mp", "Base.mc"] >>.
 
-=for html <a name="autoextend_request_path" />
-
 =item autoextend_request_path
 
 Whether to automatically add the L<top level extensions|/top_level_extensions>
 (by default ".mp" and ".mc") to the request path when searching for a matching
 page component. Defaults to true.
 
-=for html <a name="comp_root" />
-
 =item comp_root
 
 Required. The component root marks the top of your component hierarchy and
@@ -834,16 +832,12 @@ This parameter may be either a single path or an array reference of paths. If
 it is an array reference, the paths will be searched in the provided order
 whenever a component path is resolved, much like Perl's C<< @INC >>.
 
-=for html <a name="component_class_prefix" />
-
 =item component_class_prefix
 
 Prefix to use in generated component classnames. Defaults to 'MC' plus the
 interpreter's count, e.g. MC0. So a component '/foo/bar' would get a classname
 like 'MC0::foo::bar'.
 
-=for html <a name="data_dir" />
-
 =item data_dir
 
 The data directory is a writable directory that Mason uses for various features
@@ -853,38 +847,28 @@ Mason will create the directory on startup if necessary.
 Defaults to a temporary directory that will be cleaned up at process end. This
 will hurt performance as Mason will have to recompile components on each run.
 
-=for html <a name="dhandler_names" />
-
 =item dhandler_names
 
 Array reference of dhandler file names to check in order when resolving a
 top-level path. Default is C<< ["dhandler.mp", "dhandler.mc"] >>. An empty list
 disables this feature.
 
-=for html <a name="index_names" />
-
 =item index_names
 
 Array reference of index file names to check in order when resolving a
 top-level path. Default is C<< ["index.mp", "index.mc"] >>. An empty list
 disables this feature.
 
-=for html <a name="no_source_line_numbers" />
-
 =item no_source_line_numbers
 
 Do not put in source line number comments when generating code.  Setting this
 to true will cause error line numbers to reflect the real object file, rather
 than the source component.
 
-=for html <a name="object_file_extension" />
-
 =item object_file_extension
 
 Extension to add to the end of object files. Default is ".mobj".
 
-=for html <a name="plugins" />
-
 =item plugins
 
 A list of plugins and/or plugin bundles:
@@ -899,14 +883,10 @@ A list of plugins and/or plugin bundles:
 
 See L<Mason::Manual::Plugins>.
 
-=for html <a name="out_method" />
-
 =item out_method
 
 Default L<out_method|Mason::Request/out_method> passed to each new request.
 
-=for html <a name="pure_perl_extensions" />
-
 =item pure_perl_extensions
 
 A listref of file extensions of components to be considered as pure perl (see
@@ -914,8 +894,6 @@ L<Pure Perl Components|Mason::Manual::Syntax/Pure_Perl_Components>). Default is
 C<< ['.mp'] >>. If an empty list is specified, then no components will be
 considered pure perl.
 
-=for html <a name="static_source" />
-
 =item static_source
 
 True or false, default is false. When false, Mason checks the timestamp of the
@@ -932,8 +910,6 @@ L<static_source_touch_file|/static_source_touch_file>.
 We recommend turning this mode on in your production sites if possible, if
 performance is of any concern.
 
-=for html <a name="static_source_touch_file" />
-
 =item static_source_touch_file
 
 Specifies a filename that Mason will check once at the beginning of every
@@ -941,8 +917,6 @@ request when in L<static_source|/static_source> mode. When the file timestamp
 changes (indicating that a component has changed), Mason will clear its
 in-memory component cache and recheck existing object files.
 
-=for html <a name="top_level_extensions" />
-
 =item top_level_extensions
 
 A listref of file extensions of components to be considered "top level",
@@ -966,52 +940,36 @@ to create a final class, which you can get with
 
     $interp->compilation_class
 
-=for html <a name="base_code_cache_class" />
-
 =over
 
 =item base_code_cache_class
 
 Specify alternate to L<Mason::CodeCache|Mason::CodeCache>
 
-=for html <a name="base_compilation_class" />
-
 =item base_compilation_class
 
 Specify alternate to L<Mason::Compilation|Mason::Compilation>
 
-=for html <a name="base_component_class" />
-
 =item base_component_class
 
 Specify alternate to L<Mason::Component|Mason::Component>
 
-=for html <a name="base_component_moose_class" />
-
 =item base_component_moose_class
 
 Specify alternate to L<Mason::Component::Moose|Mason::Component::Moose>
 
-=for html <a name="base_component_class_meta_class" />
-
 =item base_component_class_meta_class
 
 Specify alternate to L<Mason::Component::ClassMeta|Mason::Component::ClassMeta>
 
-=for html <a name="base_component_import_class" />
-
 =item base_component_import_class
 
 Specify alternate to L<Mason::Component::Import|Mason::Component::Import>
 
-=for html <a name="base_request_class" />
-
 =item base_request_class
 
 Specify alternate to L<Mason::Request|Mason::Request>
 
-=for html <a name="base_result_class" />
-
 =item base_result_class
 
 Specify alternate to L<Mason::Result|Mason::Result>
@@ -1020,8 +978,6 @@ Specify alternate to L<Mason::Result|Mason::Result>
 
 =head1 PUBLIC METHODS
 
-=for html <a name="all_paths" />
-
 =over
 
 =item all_paths ([dir_path])
@@ -1035,28 +991,20 @@ Returns a list of distinct component paths under I<dir_path>, which defaults to
 Note that these are all component paths, not filenames, and all component roots
 are searched if there are multiple ones.
 
-=for html <a name="comp_exists" />
-
 =item comp_exists (path)
 
 Returns a boolean indicating whether a component exists for the absolute
 component I<path>.
 
-=for html <a name="count" />
-
 =item count
 
 Returns the number of this interpreter, a monotonically increasing integer for
 the process starting at 0.
 
-=for html <a name="flush_code_cache" />
-
 =item flush_code_cache
 
 Empties the component cache and removes all component classes.
 
-=for html <a name="glob_paths" />
-
 =item glob_paths (pattern)
 
 Returns a list of all component paths matching the glob I<pattern>. e.g.
@@ -1067,22 +1015,16 @@ Returns a list of all component paths matching the glob I<pattern>. e.g.
 Note that these are all component paths, not filenames, and all component roots
 are searched if there are multiple ones.
 
-=for html <a name="load" />
-
 =item load (path)
 
 Returns the component object corresponding to an absolute component I<path>, or
 undef if none exists. Dies with an error if the component fails to load because
 of a syntax error.
 
-=for html <a name="object_dir" />
-
 =item object_dir
 
 Returns the directory containing component object files.
 
-=for html <a name="run" />
-
 =item run ([request params], path, args...)
 
 Creates a new L<Mason::Request|Mason::Request> object for the given I<path> and
@@ -1097,8 +1039,6 @@ to standard output:
 
     $interp->run({out_method => sub { print $_[0] }}, '/foo/bar', baz => 5);
 
-=for html <a name="set_global" />
-
 =item set_global (varname, value)
 
 Set the global I<varname> to I<value>. This will be visible in all components
@@ -1119,8 +1059,6 @@ modify with method modifiers in L<plugins|Mason::Manual::Plugins> and
 L<subclasses|Mason::Manual::Subclasses>. Their APIs will be kept as stable as
 possible.
 
-=for html <a name="is_pure_perl_comp_path" />
-
 =over
 
 =item is_pure_perl_comp_path ($path)
@@ -1128,22 +1066,16 @@ possible.
 Determines whether I<$path> is a pure Perl component - by default, uses
 L<pure_perl_extensions|/pure_perl_extensions>.
 
-=for html <a name="is_top_level_comp_path" />
-
 =item is_top_level_comp_path ($path)
 
 Determines whether I<$path> is a valid top-level component - by default, uses
 L<top_level_extensions|/top_level_extensions>.
 
-=for html <a name="modify_loaded_class" />
-
 =item modify_loaded_class ( $compc )
 
 An opportunity to modify loaded component class I<$compc> (e.g. add additional
 methods or apply roles) before it is made immutable.
 
-=for html <a name="write_object_file" />
-
 =item write_object_file ($object_file, $object_contents)
 
 Write compiled component I<$object_contents> to I<$object_file>. This is an
@@ -1162,7 +1094,7 @@ Jonathan Swartz <swartz@pobox.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jonathan Swartz.
+This software is copyright (c) 2012 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
