@@ -1,6 +1,6 @@
 package Mason::Request;
 BEGIN {
-  $Mason::Request::VERSION = '2.19';
+  $Mason::Request::VERSION = '2.20';
 }
 use Carp;
 use File::Basename;
@@ -82,10 +82,11 @@ method cache () {
 }
 
 method capture ($code) {
+    croak "capture() expects a code reference" unless defined($code) && ref($code) eq 'CODE';
     my $output;
     {
         $self->_push_buffer;
-        scope_guard { $output = ${ $self->_current_buffer }; $self->_pop_buffer };
+        scope_guard { $output = ${ $self->_current_buffer }; $self->_pop_buffer; };
         $code->();
     }
     return $output;
@@ -346,11 +347,12 @@ method with_tied_print ($code) {
 method _apply_one_filter ($filter, $yield) {
     my $filtered_output;
     if ( ref($yield) ne 'CODE' ) {
-        my $orig_yield = $yield;
+        my $orig_yield = defined($yield) ? $yield : '';
         $yield = sub { $orig_yield };
     }
     if ( ref($filter) eq 'CODE' ) {
         local $_ = $yield->();
+        $_ = '' if !defined($_);
         $filtered_output = $filter->($_);
     }
     elsif ( blessed($filter) && $filter->can('apply_filter') ) {
@@ -365,7 +367,7 @@ method _apply_one_filter ($filter, $yield) {
 method _apply_filters () {
     my $yield = pop(@_);
     if ( ref($yield) ne 'CODE' ) {
-        my $orig_yield = $yield;
+        my $orig_yield = defined($yield) ? $yield : '';
         $yield = sub { $orig_yield };
     }
     if ( !@_ ) {
@@ -469,8 +471,6 @@ separator, regardless of what your operating system uses.
 These parameters would normally be passed in an initial hashref to  C<<
 $interp->run >>, C<< $m->visit >>, or C<< $m->go >>.
 
-=for html <a name="out_method" />
-
 =over
 
 =item out_method
@@ -491,8 +491,6 @@ L<Mason::Result|Mason::Result> object returned from C<< $interp->run >>.
 
 =head1 PUBLIC METHODS
 
-=for html <a name="abort" />
-
 =over
 
 =item abort ()
@@ -504,8 +502,6 @@ C<abort> is implemented by throwing an C<Mason::Exception::Abort> object and
 can thus be caught by C<eval>. The C<aborted> method is a shortcut for
 determining whether a caught error was generated by C<abort>.
 
-=for html <a name="aborted" />
-
 =item aborted ([$err])
 
 Returns true or undef indicating whether the specified C<$err> was generated by
@@ -521,15 +517,11 @@ letting C<abort> exceptions pass through:
         # handle fatal errors...
     };
 
-=for html <a name="add_cleanup" />
-
 =item add_cleanup (code)
 
 Add a code reference to be executed when the request is L<cleaned
 up|/cleanup_request>.
 
-=for html <a name="clear_and_abort" />
-
 =item clear_and_abort ()
 
 This method is syntactic sugar for calling C<clear_buffer()> and then
@@ -537,8 +529,6 @@ C<abort()>.  If you are aborting the request because of an error (or, in a web
 environment, to do a redirect), you will often want to clear the buffer first
 so that any output generated up to that point is not sent to the client.
 
-=for html <a name="capture" />
-
 =item capture (code)
 
 Execute the I<code>, capturing and returning any Mason output instead of
@@ -550,8 +540,6 @@ is equivalent to
 
     my $buf = $m->scomp('/foo');
 
-=for html <a name="clear_buffer" />
-
 =item clear_buffer ()
 
 Clears the Mason output buffer. Any output sent before this line is discarded.
@@ -560,8 +548,6 @@ a request.
 
 clear_buffer is, of course, thwarted by L<flush_buffer|/flush_buffer>.
 
-=for html <a name="comp" />
-
 =item comp (path[, params ...])
 
 Creates a new instance of the component designated by I<path>, and calls its
@@ -569,38 +555,28 @@ C<main> method. I<params>, if any, are passed to the constructor.
 
 The C<< <& &> >> tag provides a shortcut for C<$m-E<gt>comp>.
 
-=for html <a name="comp_exists" />
-
 =item comp_exists (path)
 
 Makes the component I<path> absolute if necessary, and calls L<Interp
 comp_exists|Mason::Interp/comp_exists> to determine whether a component exists
 at that path.
 
-=for html <a name="current_comp_class" />
-
 =item current_comp_class ()
 
 Returns the current component class. This is determined by walking up the Perl
 caller() stack until the first Mason::Component subclass is found.
 
-=for html <a name="current_request" />
-
 =item current_request ()
 
 This class method returns the C<Mason::Request> currently in use.  If called
 when no Mason request is active it will return C<undef>.
 
-=for html <a name="construct" />
-
 =item construct (path[, params ...])
 
 Constructs and return a new instance of the component designated by I<path>.
 I<params>, if any, are passed to the constructor. Throws an error if I<path>
 does not exist.
 
-=for html <a name="decline" />
-
 =item decline ()
 
 Clears the output buffer and tries the current request again, but acting as if
@@ -617,8 +593,6 @@ C</news/sports.mc>.  A call to C<< $m->decline >> would restart the request and
 resolve to C</news/dhandler.mc>, a second C<< $m->decline >> would resolve to
 C</dhandler.mc>, and a third would throw a "not found" error.
 
-=for html <a name="flush_buffer" />
-
 =item filter (filter_expr, [filter_expr...], string|coderef)
 
 Applies one or more filters to a string or to a coderef that returns a string.
@@ -633,8 +607,6 @@ request's L<out_method|/out_method>.
 Note that anything output within a C<< $m->scomp >> or C<< $m->capture >> will
 not have made it to the main output buffer, and thus cannot be flushed.
 
-=for html <a name="go" />
-
 =item go ([request params], path, args...)
 
 Performs an internal redirect. Clears the output buffer, runs a new request for
@@ -646,29 +618,21 @@ to the C<Mason::Request> constructor.
 
 See also L<visit|/visit>.
 
-=for html <a name="interp" />
-
 =item interp ()
 
 Returns the L<Interp|Mason::Interp> object associated with this request.
 
-=for html <a name="load" />
-
 =item load (path)
 
 Makes the component I<path> absolute if necessary, and calls L<Interp
 load|Mason::Interp/load> to load the component class associated with the path.
 
-=for html <a name="log" />
-
 =item log ()
 
 Returns a C<Log::Any> logger with a log category specific to the current
 component.  The category for a component "/foo/bar" would be
 "Mason::Component::foo::bar".
 
-=for html <a name="notes" />
-
 =item notes ([key[, value]])
 
 The C<notes()> method provides a place to store application data between
@@ -682,21 +646,15 @@ reference to the entire hash of key-value pairs.
 Consider storing this kind of data in a read-write attribute of the page
 component.
 
-=for html <a name="print" />
-
 =item print (string)
 
 Add the given I<string> to the Mason output buffer. This happens implicitly for
 all content placed in the main component body.
 
-=for html <a name="page" />
-
 =item page ()
 
 Returns the page component originally called in the request.
 
-=for html <a name="path_info" />
-
 =item path_info ()
 
 Returns the remainder of the request path beyond the path of the page
@@ -707,28 +665,20 @@ path_info with
 
     if ( length($m->path_info) )
 
-=for html <a name="rel_to_abs" />
-
 =item rel_to_abs (path)
 
 Converts a component I<path> to absolute form based on the current component,
 if it does not already begin with a '/'.
 
-=for html <a name="request_args" />
-
 =item request_args ()
 
 Returns the original hashref of arguments passed to the request, e.g. via C<<
 $interp->run >>.
 
-=for html <a name="request_path" />
-
 =item request_path ()
 
 Returns the original path passed to the request, e.g. in C<< $interp->run >>.
 
-=for html <a name="scomp" />
-
 =item scomp (comp, args...)
 
 Like L<comp|Mason::Request/item_comp>, but returns the component output as a
@@ -736,8 +686,6 @@ string instead of printing it. (Think sprintf versus printf.)
 
 See also L<capture|/capture>.
 
-=for html <a name="visit" />
-
 =item visit ([request params], path, args...)
 
 Performs a subrequest with the given I<path> and I<args>, with output being
@@ -760,8 +708,6 @@ modify with method modifiers in L<plugins|Mason::Manual::Plugins> and
 L<subclasses|Mason::Manual::Subclasses>. Their APIs will be kept as stable as
 possible.
 
-=for html <a name="cleanup_request" />
-
 =over
 
 =item cleanup_request ()
@@ -770,15 +716,11 @@ A place to perform cleanup duties when the request finishes or dies with an
 error, even if the request object is not immediately destroyed. Includes
 anything registered with L<add_cleanup|/add_cleanup>.
 
-=for html <a name="construct_page_component" />
-
 =item construct_page_component ($compc, $args)
 
 Constructs the page component of class I<$compc>, with hashref of constructor
 arguments I<$args>.
 
-=for html <a name="match_request_path" />
-
 =item match_request_path ($request_path)
 
 Given a top level I<$request_path>, return a corresponding component path or
@@ -791,15 +733,11 @@ This method is called on the output buffer right before it is sent to its final
 destination. I<$outref> is a reference to the output string; the method can
 modify it as desired.
 
-=for html <a name="run" />
-
 =item run ($request_path, args)
 
 Runs the request with I<$request_path> and I<args>, where the latter can be
 either a hashref or a hash. This is generally called via << $interp->run >>.
 
-=for html <a name="with_tied_print" />
-
 =item with_tied_print ($code)
 
 Execute the given I<$code> with the current selected filehandle ('print') tied
@@ -818,7 +756,7 @@ Jonathan Swartz <swartz@pobox.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jonathan Swartz.
+This software is copyright (c) 2012 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
