@@ -1,6 +1,6 @@
 package Mason::Test::Class;
 BEGIN {
-  $Mason::Test::Class::VERSION = '2.19';
+  $Mason::Test::Class::VERSION = '2.20';
 }
 use Carp;
 use File::Basename;
@@ -25,7 +25,7 @@ sub temp_root { $_[0]->{temp_root} }
 
 # RW class accessors
 my $default_plugins = [];
-sub default_plugins { $default_plugins = $_[1] if defined( $_[1] ); $default_plugins }
+sub default_plugins { $default_plugins = $_[1] if defined( $_[1] ); $default_plugins; }
 
 my $gen_path_count = 0;
 my $parse_count    = 0;
