@@ -1,10 +1,15 @@
 package Mason::Test::Overrides::Component::StrictMoose;
 BEGIN {
-  $Mason::Test::Overrides::Component::StrictMoose::VERSION = '2.19';
+  $Mason::Test::Overrides::Component::StrictMoose::VERSION = '2.20';
 }
 use Moose::Exporter;
 use MooseX::StrictConstructor ();
+use strict;
+use warnings;
 use base qw(Mason::Component::Moose);
+use strict;
+use warnings;
+
 Moose::Exporter->setup_import_methods();
 
 sub init_meta {
